validate

Function validate 

pub fn validate(query: &mut GqlQuery) -> Result<(), QueryError>
Validate and normalise an AST in place.

On success, every kind / relation string in the AST is replaced with its canonical lowercase form so the compiler can emit literal SQL parameters that match the values written by khive-db.