Compile GQL AST to parameterized SQL (JOIN chain or recursive CTE).
Structs
- Compile
Options - Runtime options injected by the caller to scope and cap query execution.
- Compiled
Query - Parameterized SQL emitted by the compiler, ready for execution by the runtime.
- Truncation
Check - See
CompiledQuery::truncation_check.
Functions
- compile
- Compile a
GqlQueryAST to a parameterized SQL string and bound parameters.